==> go.php?file=PhoenixStyle1.56305.zip: PhoenixStyleMod_DragonSoul/Localization/localization-enEN.lua <==
﻿


function psdragslocalem()

psdragslastmoduleloadtxt	= "Dragon Soul"

pszzdragoboss7          = "Spine of Deathwing"
pszzdragoboss8          = "Madness of Deathwing"

pszzdragotxtopt613			= "|tip1 Report if someone die from melee or crush strike with more than 1 stack of |sid33661|id"
pszzdragotxtopt621			= "|tip2 How much heal boss received from |sid104322|id and who failed"
pszzdragotxtopt622			= "|tip1 If more than 1 raider got damage from |sid104322|id"
pszzdragotxtopt645			= "|tip1 Report stacks quantity when someone die from |sid107062|id"
pszzdragotxtopt664			= "|tip1 Report info about |sid109204|id when someone die from |sid109227|id or |sid109205|id"
pszzdragotxtopt665			= "|tip1 Report info if someone die from |sid109227|id or |sid109205|id"
pszzdragotxtopt666			= "|cff00ff00Boss_shieldsmonitor|r - show |sid110598|id absorb HP, if addon is installed"
pszzdragotxtopt671			= "|cff00ff00Boss_shieldsmonitor|r - show |sid109362|id absorb HP, if addon is installed"
pszzdragotxtopt672			= "|tip2 Who healed |sid105479|id (absorb)"
pszzdragotxtopt674			= "|tip3 Save info in 'Damage/Switch info' about damage done to Hideous Amalgamation (last 10%) and Burning Tendons"
pszzdragotxtopt675			= "|tip1 Who made damage to Hideous Amalgamation (last 10%) if it die without casting |sid105845|id"
pszzdragotxtopt681			= "|tip3 Save info in 'Damage/Switch info' about damage done to Elementium Bolt"
pszzdragotxtopt682      = "|tip2 Show total damage that was absorbed (approximately) using |sid106466|id spell"
pszzdragotxtopt683      = "|tip2 Show who doesn`t use |sid106466|id spell"
pszzdragotxtopt684      = "|tip1 Show if someone die from |sid110139|id without using |sid106466|id (normal) or with other CD available (heroic)"
pszzdragotxtopt685      = "|tip4 Mark adds that start casting |sid110139|id in players which doesn`t have an ability to avoid damage"


pszzdragotxtoptt672     = "Heal absorbed by |s4id105479,109362,109363,109364|id"
pszzdragotxtoptt622	= "|s4id104322,104606,104607,104608|id damaged %s"
pszzdragonly10		= "only <10% HP"
pszzdragdamageinfly	= "only before explosion"
pszzdragdamageinfly2	= "total damage (no slow)"
pszzdragotxtoptt682     = "Damage absorbed by |s4id106466,109634,109635,109636|id (approximately)"
pszzdragtextbuttonuse1	= "|s4id106466,109634,109635,109636|id was USED only by"
pszzdragtextbuttonuse2	= "|s4id106466,109634,109635,109636|id was NOT used by"
pszzdragtextbuttonuse3 	= "|s4id106466,109634,109635,109636|id was NOT used by %s players!"
pszzdraghpontheendcast	= "HP left at the end of cast"
pszzdragdiedtoquick     = "Died without 9 stacks!"
pszzdraghpremain         = "HP remain"
pszzdragsplit           = "Split"
pszzdragdiedwarmast     = "Died (player HP before split)"
pszzdragothercd         = "Available CD"
pszzdragdamagetoplayer  = "Damage to player"
pszzdragdamageto        = "Damage to"
pszzdraghealedby        = "Healed by"



end

==> go.php?file=PhoenixStyle1.56402.zip: PhoenixStyleMod_DragonSoul/Localization/localization-enEN.lua <==
﻿


function psdragslocalem()

psdragslastmoduleloadtxt	= "Dragon Soul"

pszzdragoboss7          = "Spine of Deathwing"
pszzdragoboss8          = "Madness of Deathwing"

pszzdragotxtopt613			= "|tip1 Report if someone die from melee or crush strike with more than 1 stack of |sid33661|id"
pszzdragotxtopt621			= "|tip2 How much heal boss received from |sid104322|id and who failed"
pszzdragotxtopt622			= "|tip1 If more than 1 raider got damage from |sid104322|id"
pszzdragotxtopt645			= "|tip1 Report stacks quantity when someone die from |sid107062|id"
pszzdragotxtopt664			= "|tip1 Report info about |sid109204|id when someone die from |sid109227|id or |sid109205|id"
pszzdragotxtopt665			= "|tip1 Report info if someone die from |sid109227|id or |sid109205|id"
pszzdragotxtopt666			= "|cff00ff00Boss_shieldsmonitor|r - show |sid110598|id absorb HP, if addon is installed"
pszzdragotxtopt671			= "|cff00ff00Boss_shieldsmonitor|r - show |sid109362|id absorb HP, if addon is installed"
pszzdragotxtopt672			= "|tip2 Who healed |sid105479|id (absorb)"
pszzdragotxtopt674			= "|tip3 Save info in 'Damage/Switch info' about damage done to Hideous Amalgamation (last 10%) and Burning Tendons"
pszzdragotxtopt675			= "|tip1 Who made damage to Hideous Amalgamation (last 10%) if it die without casting |sid105845|id"
pszzdragotxtopt681			= "|tip3 Save info in 'Damage/Switch info' about damage done to Elementium Bolt"
pszzdragotxtopt682      = "|tip2 Show total damage that was absorbed (approximately) using |sid106466|id spell"
pszzdragotxtopt683      = "|tip2 Show who doesn`t use |sid106466|id spell"
pszzdragotxtopt684      = "|tip1 Show if someone die from |sid110139|id without using |sid106466|id (normal) or with other CD available (heroic)"
pszzdragotxtopt685      = "|tip4 Mark adds that start casting |sid110139|id in players which doesn`t have an ability to avoid damage"


pszzdragotxtoptt672     = "Heal absorbed by |s4id105479,109362,109363,109364|id"
pszzdragotxtoptt622	= "|s4id104322,104606,104607,104608|id damaged %s"
pszzdragonly10		= "only <10% HP"
pszzdragdamageinfly	= "only before explosion"
pszzdragdamageinfly2	= "total damage (no slow)"
pszzdragotxtoptt682     = "Damage absorbed by |s4id106466,109634,109635,109636|id (approximately)"
pszzdragtextbuttonuse1	= "|s4id106466,109634,109635,109636|id was USED only by"
pszzdragtextbuttonuse2	= "|s4id106466,109634,109635,109636|id was NOT used by"
pszzdragtextbuttonuse3 	= "|s4id106466,109634,109635,109636|id was NOT used by %s players!"
pszzdraghpontheendcast	= "HP left at the end of cast"
pszzdragdiedtoquick     = "Died without 9 stacks!"
pszzdraghpremain         = "HP remain"
pszzdragsplit           = "Split"
pszzdragdiedwarmast     = "Died (player HP before split)"
pszzdragothercd         = "Available CD"
pszzdragdamagetoplayer  = "Damage to player"
pszzdragdamageto        = "Damage to"
pszzdraghealedby        = "Healed by"
pszzdragspineexamp      = "|cff00ff00EXAMPLE:|r Player with grip, time spent to break it. Damage to player: <number>. Damage to Corruption (while grip was on + 1 sec after it finished): who did damage. Failed damage is considered for 1-11 sec after grip was broken."
pszzdragspinefaildmg    = "Failed damage"



end
